<?php

/**
 * Create the General Settings section
 */
add_action('admin_init', 'zilla_general_settings');
function zilla_general_settings(){
    $general_settings['description'] = 'Control and configure the general setup of your theme.';
                                
	$general_settings[] = array(
        'title' => __('Plain Text Logo', 'zilla'),
        'desc' => __('Check this box to enable a plain text logo rather than using the Custom Logo Upload. Your site name will be used as the plain text logo.', 'zilla'),
        'type' => 'checkbox',
        'id' => 'general_text_logo'
    );
                                
	$general_settings[] = array(
        'title' => __('Custom Logo Upload', 'zilla'),
        'desc' => __('Upload your logo for your website.', 'zilla'),
        'type' => 'file',
        'id' => 'general_custom_logo',
        'val' => 'Upload Image'
    );
								
    $general_settings[] = array(
        'title' => __('Custom Favicon Upload', 'zilla'),
        'desc' => __('Upload a 16px x 16px .png or .gif image that will represent your website\'s favicon.', 'zilla'),
        'type' => 'file',
        'id' => 'general_custom_favicon',
        'val' => 'Upload Image'
    );

    $general_settings[] = array(
        'title' => __('Default Blog Page Title', 'zilla'),
        'desc' => __('Please enter a default page title for your blog.', 'zilla'),
        'type' => 'text',
        'id' => 'general_default_page_title'
    );

    $general_settings[] = array(
        'title' => __('Default Blog Page Caption', 'zilla'),
        'desc' => __('Please enter a default page caption for your blog.', 'zilla'),
        'type' => 'text',
        'id' => 'general_default_page_caption'
    );

    $general_settings[] = array(
        'title' => __('Portfolio Page', 'zilla'),
        'desc' => __('Please select your portfolio page.', 'zilla'),
        'type' => 'pages',
        'id' => 'general_portfolio_page'
    );
                                
    $general_settings[] = array(
        'title' => __('Contact Form Email Address', 'zilla'),
        'desc' => __('Enter the email address where you\'d like to receive emails from the contact form, or leave blank to use admin email.', 'zilla'),
        'type' => 'text',
        'id' => 'general_contact_email'
    );
                        
    $general_settings[] = array(
        'title' => __('FeedBurner URL', 'zilla'),
        'desc' => __('Enter your full FeedBurner URL (or any other preferred feed URL) if you wish to use FeedBurner over the standard WordPress feed e.g. http://feeds.feedburner.com/yoururlhere', 'zilla'),
        'type' => 'text',
        'id' => 'general_feedburner_url'
    );
                        
    $general_settings[] = array(
        'title' => __('Tracking Code', 'zilla'),
        'desc' => __('Paste your Google Analytics (or other) tracking code here. It will be inserted before the closing body tag of your theme. You should enter Javascript code provided by your analytics provider.', 'zilla'),
        'type' => 'textarea',
        'id' => 'general_tracking_code'
    );
                                
    zilla_add_framework_page( 'General Settings', $general_settings, 5 );
}


/**
 * Output the favicon
 */
function zilla_custom_favicon(){
    $zilla_values = get_option( 'zilla_framework_values' );
    if( array_key_exists( 'general_custom_favicon', $zilla_values ) && $zilla_values['general_custom_favicon'] != '' )
        echo '<link rel="shortcut icon" href="'. $zilla_values['general_custom_favicon'] .'" />' . "\n";
}
add_action( 'wp_head', 'zilla_custom_favicon' );

/**
 * Redirect the RSS feed
 * Credit: Feedburner Feedsmith Plugin
 */
if( !preg_match("/feedburner|feedvalidator/i", $_SERVER['HTTP_USER_AGENT']) ){
	add_action( 'template_redirect', 'zilla_feed_redirect' );
	add_action( 'init', 'zilla_check_url' );
}
if( !function_exists('zilla_feed_redirect') ) {
    function zilla_feed_redirect() {
    	global $wp, $feed, $withcomments;
        
        $zilla_values = get_option( 'zilla_framework_values' );
        if( array_key_exists( 'general_feedburner_url', $zilla_values ) && $zilla_values['general_feedburner_url'] != '' ){
            if( is_feed() && $feed != 'comments-rss2' && !is_single() && $wp->query_vars['category_name'] == '' && ($withcomments != 1) ){
                if( function_exists('status_header') ) status_header( 302 );
                header("Location:" . trim($zilla_values['general_feedburner_url']));
                header("HTTP/1.1 302 Temporary Redirect");
                exit();
            }
        }
    }
}
if( !function_exists('zilla_check_url') ) {
    function zilla_check_url() {
    	$zilla_values = get_option( 'zilla_framework_values' );
        if( array_key_exists( 'general_feedburner_url', $zilla_values ) && $zilla_values['general_feedburner_url'] != '' ){
            switch( basename($_SERVER['PHP_SELF']) ){
                case 'wp-rss.php':
                case 'wp-rss2.php':
                case 'wp-atom.php':
                case 'wp-rdf.php':
                    if( function_exists('status_header') ) status_header( 302 );
                    header("Location:" . trim($zilla_values['general_feedburner_url']));
                    header("HTTP/1.1 302 Temporary Redirect");
                    exit();
                    break;
            }
        }
    }
}

/**
 * Output the tracking code
 */
if( !function_exists('zilla_tracking_code') ) {
    function zilla_tracking_code(){
        $zilla_values = get_option( 'zilla_framework_values' );
        if( array_key_exists( 'general_tracking_code', $zilla_values ) && $zilla_values['general_tracking_code'] != '' )
            echo stripslashes($zilla_values['general_tracking_code']);
    }
}
add_action( 'wp_footer', 'zilla_tracking_code' );